import akka.actor.*;

public class Sample {
  public static void doSequential() {
    long start = System.nanoTime();
    
    StockInfo highPriced = new StockInfo("", 0.0);
    for(String ticker : Stocks.tickers) {
      StockInfo stockInfo = 
        new StockInfo(ticker, YahooFinance.getPrice(ticker));
      if(stockInfo.price > highPriced.price) {
        highPriced = stockInfo;
      }
    }
    
    long end = System.nanoTime();
    
    System.out.println("High priced " + highPriced);
    System.out.println("Time taken " + (end - start)/1.0e9);
  }
    
  public static void doConcurrent() {
    final ActorSystem actorSystem = ActorSystem.create();
    
    final ActorRef stockCollector = 
      actorSystem.actorOf(new Props(StockCollector.class));
    
    stockCollector.tell(Stocks.tickers.length);
    
    for(String ticker : Stocks.tickers) {
      final String theTicker = ticker;
      //Better to use ExecutorService here or even better some actors, but
      //we will keep it simple here.
      
      new Thread(new Runnable() {
        public void run() {
          stockCollector.tell(
            new StockInfo(theTicker, YahooFinance.getPrice(theTicker)));              
        }
      }).start();
    }
  }
  
  public static void main(String[] args) throws Exception {
    doSequential();    
    doConcurrent();
  }
}
